part of appsize;

/// {@template app_size_util}
/// The util class with all the stuff that we use to get the size of the app.
/// {@endtemplate}
class AppSizeUtil {
  /// Device's BoxConstraints.
  static late BoxConstraints boxConstraints;

  /// Device's Orientation.
  static late Orientation orientation;

  /// Type of Device.
  ///
  /// This can either be mobile or tablet.
  static late DeviceType deviceType;

  /// Device's Height.
  static late double height;

  /// Device's Width.
  static late double width;

  /// The amount of required to multiply the size to get a pixel.
  static const pixelRatio = 0.00243;

  /// The width of the platform multiplied by the pixelRatio.
  double get scalablePixel => width * pixelRatio;

  /// Returns xxx small size from 4 pixels.
  double get xxxSmall => 4.sp;

  /// Returns xx small size from 8 pixels.
  double get xxSmall => 8.sp;

  /// Returns x small size from 16 pixels.
  double get xSmall => 16.sp;

  /// Returns small size from 32 pixels.
  double get small => 32.sp;

  /// Returns medium size from 48 pixels.
  double get medium => 48.sp;

  /// Returns large size from 64 pixels.
  double get large => 64.sp;

  /// Returns x large size from 80 pixels.
  double get xLarge => 80.sp;

  /// Returns xx large size from 96 pixels.
  double get xxLarge => 96.sp;

  /// Sets the Screen's size and Device's Orientation,
  /// BoxConstraints, Height, and Width.
  static void setScreenSize(
    BoxConstraints constraints,
    Orientation currentOrientation,
  ) {
    // Sets boxconstraints and orientation.
    boxConstraints = constraints;
    orientation = currentOrientation;

    // Sets screen width and height.
    if (orientation == Orientation.portrait) {
      width = boxConstraints.maxWidth;
      height = boxConstraints.maxHeight;
    } else {
      width = boxConstraints.maxHeight;
      height = boxConstraints.maxWidth;
    }

    // Sets ScreenType.
    if (kIsWeb) {
      deviceType = DeviceType.web;
    } else if (Platform.isAndroid || Platform.isIOS) {
      if ((orientation == Orientation.portrait && width < 600) ||
          (orientation == Orientation.landscape && height < 600)) {
        deviceType = DeviceType.mobile;
      } else {
        deviceType = DeviceType.tablet;
      }
    } else if (Platform.isMacOS) {
      deviceType = DeviceType.mac;
    } else if (Platform.isWindows) {
      deviceType = DeviceType.windows;
    } else if (Platform.isLinux) {
      deviceType = DeviceType.linux;
    } else {
      deviceType = DeviceType.fuchsia;
    }
  }

  /// For responsive web.
  static dynamic getWebResponsiveSize({
    dynamic smallSize,
    dynamic mediumSize,
    dynamic largeSize,
  }) {
    if (width < 600) {
      return smallSize; //'phone'.
    } else if (width >= 600 && width <= 1024) {
      return mediumSize; //'tablet'.
    }
    return largeSize; //'desktop'.
  }
}

/// Type of Device.
///
/// This can be either mobile or tablet.
enum DeviceType {
  /// Mobile Device.
  mobile,

  /// Tablet Device.
  tablet,

  /// Web Device.
  web,

  /// Mac OS Device.
  mac,

  /// Windows OS Device.
  windows,

  /// Linux OS Device.
  linux,

  /// Fuchsia distro Device.
  fuchsia,
}
