part of appsize;

/// Provides `Context`, `Orientation`, and `DeviceType` parameters
/// to the builder function.
typedef ResponsiveBuild = Widget Function(
  BuildContext context,
  Orientation orientation,
  DeviceType deviceType,
);

/// {@template app_size}
/// The Widget that gets the device's details like orientation and constraints.
///
/// Usage: Wrap MaterialApp with this widget.
/// {@endtemplate}
class AppSize extends StatelessWidget {
  /// {@macro app_size}
  const AppSize({super.key, required this.builder});

  /// Builds the widget whenever the orientation changes
  final ResponsiveBuild builder;

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (context, constraints) {
        return OrientationBuilder(
          builder: (context, orientation) {
            AppSizeUtil.setScreenSize(constraints, orientation);
            return builder(context, orientation, AppSizeUtil.deviceType);
          },
        );
      },
    );
  }
}
